.. Mosaic documentation master file, created by
   sphinx-quickstart on Wed Dec 12 17:31:08 2012.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Mosaic's documentation!
==================================

Contents:

.. toctree::
   :maxdepth: 2

   data_model
   python_api
   tools

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

